@@ -6,6 +6,8 @@ Methods for abstract circuits independent of nodes, edges and contractions
 from typing import Any, Callable, Dict, List, Optional, Sequence, Union, Tuple
 from functools import reduce
 from operator import add
+import json
+import logging
 
 import numpy as np
 import tensornetwork as tn
@@ -15,30 +17,36 @@ from .cons import backend, dtypestr
 from .vis import qir2tex
 from .quantum import QuOperator
 
+logger = logging.getLogger(__name__)
 
 Gate = gates.Gate
 Tensor = Any
 
 sgates = (
     ["i", "x", "y", "z", "h", "t", "s", "td", "sd", "wroot"]
-    + ["cnot", "cz", "swap", "cy", "iswap", "ox", "oy", "oz"]
+    + ["cnot", "cz", "swap", "cy", "ox", "oy", "oz"]
     + ["toffoli", "fredkin"]
 )
 vgates = [
     "r",
     "cr",
+    "u",
+    "cu",
     "rx",
     "ry",
     "rz",
+    "phase",
     "rxx",
     "ryy",
     "rzz",
+    "cphase",
     "crx",
     "cry",
     "crz",
     "orx",
     "ory",
     "orz",
+    "iswap",
     "any",
     "exp",
     "exp1",
@@ -48,7 +56,10 @@ gate_aliases = [
     ["cnot", "cx"],
     ["fredkin", "cswap"],
     ["toffoli", "ccnot"],
+    ["toffoli", "ccx"],
     ["any", "unitary"],
+    ["sd", "sdg"],
+    ["td", "tdg"],
 ]
 
 
@@ -426,6 +437,67 @@ class AbstractCircuit:
         """
         self._apply_qir(self, qir)
 
+    @staticmethod
+    def standardize_gate(name: str) -> str:
+        """
+        standardize the gate name to tc common gate sets
+
+        :param name: non-standard gate name
+        :type name: str
+        :return: the standard gate name
+        :rtype: str
+        """
+        name = name.lower()
+        for g1, g2 in gate_aliases:
+            if name == g2:
+                name = g1
+                break
+        if name not in sgates + vgates + mpogates:
+            logger.warning("gate name not in the common gate set that tc supported")
+        return name
+
+    def gate_count(self, gate_list: Optional[Sequence[str]] = None) -> int:
+        """
+        count the gate number of the circuit
+
+        :Example:
+
+        >>> c = tc.Circuit(3)
+        >>> c.h(0)
+        >>> c.multicontrol(0, 1, 2, ctrl=[0, 1], unitary=tc.gates._x_matrix)
+        >>> c.toffolli(1, 2, 0)
+        >>> c.gate_count()
+        3
+        >>> c.gate_count(["multicontrol", "toffoli"])
+        2
+
+        :param gate_list: gate name list to be counted, defaults to None (counting all gates)
+        :type gate_list: Optional[Sequence[str]], optional
+        :return: the total number of all gates or gates in the ``gate_list``
+        :rtype: int
+        """
+        if gate_list is None:
+            return len(self._qir)
+        else:
+            gate_list = [self.standardize_gate(g) for g in gate_list]
+            c = 0
+            for d in self._qir:
+                if d["name"] in gate_list:
+                    c += 1
+            return c
+
+    def gate_summary(self) -> Dict[str, int]:
+        """
+        return the summary dictionary on gate type - gate count pair
+
+        :return: the gate count dict by gate type
+        :rtype: Dict[str, int]
+        """
+        summary: Dict[str, int] = {}
+        for d in self._qir:
+            summary[d["name"]] = summary.get(d["name"], 0) + 1
+        return summary
+
     def to_qiskit(self) -> Any:
         """
         Translate ``tc.Circuit`` to a qiskit QuantumCircuit object.
@@ -508,6 +580,66 @@ class AbstractCircuit:
 
     tex = vis_tex
 
+    def to_json(self, file: Optional[str] = None, simplified: bool = False) -> Any:
+        """
+        circuit dumps to json
+
+        :param file: file str to dump the json to, defaults to None, return the json str
+        :type file: Optional[str], optional
+        :param simplified: If False, keep all info for each gate, defaults to be False.
+            If True, suitable for IO since less information is required
+        :type simplified: bool
+        :return: None if dumps to file otherwise the json str
+        :rtype: Any
+        """
+        from .translation import qir2json
+
+        tcqasm = qir2json(self.to_qir(), simplified=simplified)
+        if file is not None:
+            with open(file, "w") as f:
+                json.dump(tcqasm, f)
+        return json.dumps(tcqasm)
+
+    @classmethod
+    def from_json(
+        cls, jsonstr: str, circuit_params: Optional[Dict[str, Any]] = None
+    ) -> "AbstractCircuit":
+        """
+        load json str as a Circuit
+
+        :param jsonstr: _description_
+        :type jsonstr: str
+        :param circuit_params: Extra circuit parameters in the format of ``__init__``,
+            defaults to None
+        :type circuit_params: Optional[Dict[str, Any]], optional
+        :return: _description_
+        :rtype: AbstractCircuit
+        """
+        from .translation import json2qir
+
+        if isinstance(jsonstr, str):
+            jsonstr = json.loads(jsonstr)
+        qir = json2qir(jsonstr)  # type: ignore
+        return cls.from_qir(qir, circuit_params)
+
+    @classmethod
+    def from_json_file(
+        cls, file: str, circuit_params: Optional[Dict[str, Any]] = None
+    ) -> "AbstractCircuit":
+        """
+        load json file and convert it to a circuit
+
+        :param file: filename
+        :type file: str
+        :param circuit_params: _description_, defaults to None
+        :type circuit_params: Optional[Dict[str, Any]], optional
+        :return: _description_
+        :rtype: AbstractCircuit
+        """
+        with open(file, "r") as f:
+            jsonstr = json.load(f)
+        return cls.from_json(jsonstr, circuit_params)
+
     def select_gate(self, which: Tensor, kraus: Sequence[Gate], *index: int) -> None:
         """
         Apply ``which``-th gate from ``kraus`` list, i.e. apply kraus[which]
