@@ -4,16 +4,26 @@ Quantum circuit: common methods for all circuit classes as MixIn
 # pylint: disable=invalid-name
 
 from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
+from functools import partial
 
 import numpy as np
 import graphviz
 import tensornetwork as tn
 
 from . import gates
-from .quantum import QuOperator, QuVector
+from .quantum import (
+    QuOperator,
+    QuVector,
+    correlation_from_counts,
+    measurement_counts,
+    sample_int2bin,
+    sample_bin2int,
+    sample2all,
+)
 from .abstractcircuit import AbstractCircuit
 from .cons import npdtype, backend, dtypestr, contractor, rdtypestr
 from .simplify import _split_two_qubit_gate
+from .utils import arg_alias
 
 Gate = gates.Gate
 Tensor = Any
@@ -302,49 +312,6 @@ class BaseCircuit(AbstractCircuit):
                 newdang[j] ^ newdang[j + nq]
         return nodes  # type: ignore
 
-    def expectation_ps(
-        self,
-        x: Optional[Sequence[int]] = None,
-        y: Optional[Sequence[int]] = None,
-        z: Optional[Sequence[int]] = None,
-        reuse: bool = True,
-        **kws: Any,
-    ) -> Tensor:
-        """
-        Shortcut for Pauli string expectation.
-        x, y, z list are for X, Y, Z positions
-
-        :Example:
-
-        >>> c = tc.Circuit(2)
-        >>> c.X(0)
-        >>> c.H(1)
-        >>> c.expectation_ps(x=[1], z=[0])
-        array(-0.99999994+0.j, dtype=complex64)
-
-        :param x: _description_, defaults to None
-        :type x: Optional[Sequence[int]], optional
-        :param y: _description_, defaults to None
-        :type y: Optional[Sequence[int]], optional
-        :param z: _description_, defaults to None
-        :type z: Optional[Sequence[int]], optional
-        :param reuse: whether to cache and reuse the wavefunction, defaults to True
-        :type reuse: bool, optional
-        :return: Expectation value
-        :rtype: Tensor
-        """
-        obs = []
-        if x is not None:
-            for i in x:
-                obs.append([gates.x(), [i]])  # type: ignore
-        if y is not None:
-            for i in y:
-                obs.append([gates.y(), [i]])  # type: ignore
-        if z is not None:
-            for i in z:
-                obs.append([gates.z(), [i]])  # type: ignore
-        return self.expectation(*obs, reuse=reuse, **kws)  # type: ignore
-
     def to_qir(self) -> List[Dict[str, Any]]:
         """
         Return the quantum intermediate representation of the circuit.
@@ -393,9 +360,7 @@ class BaseCircuit(AbstractCircuit):
         :return: Sampled bit string and the corresponding theoretical probability.
         :rtype: Tuple[str, float]
         """
-        return self.measure_jit(
-            *[i for i in range(self._nqubits)], with_prob=True, status=status
-        )
+        return self.measure_jit(*range(self._nqubits), with_prob=True, status=status)
 
     def measure_jit(
         self, *index: int, with_prob: bool = False, status: Optional[Tensor] = None
@@ -536,11 +501,13 @@ class BaseCircuit(AbstractCircuit):
             no.extend(msconj)
         return contractor(no).tensor
 
+    @partial(arg_alias, alias_dict={"format": ["format_"]})
     def sample(
         self,
         batch: Optional[int] = None,
         allow_state: bool = False,
-        status: Optional[Tensor] = None,
+        format: Optional[str] = None,
+        random_generator: Optional[Any] = None,
     ) -> Any:
         """
         batched sampling from state or circuit tensor network directly
@@ -550,61 +517,146 @@ class BaseCircuit(AbstractCircuit):
         :param allow_state: if true, we sample from the final state
             if memory allsows, True is prefered, defaults to False
         :type allow_state: bool, optional
-        :param status: random generator,  defaults to None
-        :type status: Optional[Tensor], optional
+        :param format: sample format, defaults to None as backward compatibility
+            check the doc in :py:meth:`tensorcircuit.quantum.measurement_results`
+        :type format: Optional[str]
+        :param random_generator: random generator,  defaults to None
+        :type random_generator: Optional[Any], optional
         :return: List (if batch) of tuple (binary configuration tensor and correponding probability)
+            if the format is None, and consitent with format when given
         :rtype: Any
         """
         # allow_state = False is compatibility issue
         if not allow_state:
-            if status is None:
-                status = backend.get_random_state()
+            if random_generator is None:
+                random_generator = backend.get_random_state()
 
             if batch is None:
-                seed = backend.stateful_randu(status, shape=[self._nqubits])
-                return self.perfect_sampling(seed)
+                seed = backend.stateful_randu(random_generator, shape=[self._nqubits])
+                r = self.perfect_sampling(seed)
+                if format is None:  # batch=None, format=None, backward compatibility
+                    return r
+                r = [r]  # type: ignore
+            else:
 
-            @backend.jit  # type: ignore
-            def perfect_sampling(key: Any) -> Any:
-                backend.set_random_state(key)
-                return self.perfect_sampling()
+                @backend.jit  # type: ignore
+                def perfect_sampling(key: Any) -> Any:
+                    backend.set_random_state(key)
+                    return self.perfect_sampling()
 
-            r = []
+                r = []  # type: ignore
 
-            subkey = status
-            for _ in range(batch):
-                key, subkey = backend.random_split(subkey)
-                r.append(perfect_sampling(key))
+                subkey = random_generator
+                for _ in range(batch):
+                    key, subkey = backend.random_split(subkey)
+                    r.append(perfect_sampling(key))  # type: ignore
+            if format is None:
+                return r
+            r = backend.stack([ri[0] for ri in r])  # type: ignore
+            r = backend.cast(r, "int32")
+            ch = sample_bin2int(r, self._nqubits)
+        else:  # allow_state
+            if batch is None:
+                nbatch = 1
+            else:
+                nbatch = batch
+            s = self.state()  # type: ignore
+            if self.is_dm is False:
+                p = backend.abs(s) ** 2
+            else:
+                p = backend.abs(backend.diagonal(s))
+            a_range = backend.arange(2**self._nqubits)
+            if random_generator is None:
+                ch = backend.implicit_randc(a=a_range, shape=[nbatch], p=p)
+            else:
+                ch = backend.stateful_randc(
+                    random_generator, a=a_range, shape=[nbatch], p=p
+                )
+            # confg = backend.mod(
+            #     backend.right_shift(
+            #         ch[..., None], backend.reverse(backend.arange(self._nqubits))
+            #     ),
+            #     2,
+            # )
+            if format is None:
+                confg = sample_int2bin(ch, self._nqubits)
+                prob = backend.gather1d(p, ch)
+                r = list(zip(confg, prob))  # type: ignore
+                if batch is None:
+                    r = r[0]  # type: ignore
+                return r
+        return sample2all(sample=ch, n=self._nqubits, format=format, jittable=True)
 
-            return r
+    def sample_expectation_ps(
+        self,
+        x: Optional[Sequence[int]] = None,
+        y: Optional[Sequence[int]] = None,
+        z: Optional[Sequence[int]] = None,
+        shots: Optional[int] = None,
+        random_generator: Optional[Any] = None,
+        **kws: Any,
+    ) -> Tensor:
+        """
+        Compute the expectation with given Pauli string with measurement shots numbers
 
-        if batch is None:
-            nbatch = 1
-        else:
-            nbatch = batch
-        s = self.state()  # type: ignore
+        :Example:
+
+        >>> c = tc.Circuit(2)
+        >>> c.H(0)
+        >>> c.rx(1, theta=np.pi/2)
+        >>> c.sample_expectation_ps(x=[0], y=[1])
+        -0.99999976
+
+        :param x: index for Pauli X, defaults to None
+        :type x: Optional[Sequence[int]], optional
+        :param y: index for Pauli Y, defaults to None
+        :type y: Optional[Sequence[int]], optional
+        :param z: index for Pauli Z, defaults to None
+        :type z: Optional[Sequence[int]], optional
+        :param shots: number of measurement shots, defaults to None, indicating analytical result
+        :type shots: Optional[int], optional
+        :param random_generator: random_generator, defaults to None
+        :type random_general: Optional[Any]
+        :return: [description]
+        :rtype: Tensor
+        """
         if self.is_dm is False:
+            c = type(self)(self._nqubits, mps_inputs=self.quvector())  # type: ignore
+        else:
+            c = type(self)(self._nqubits, mpo_dminputs=self.get_dm_as_quoperator())  # type: ignore
+        if x is None:
+            x = []
+        if y is None:
+            y = []
+        if z is None:
+            z = []
+        for i in x:
+            c.H(i)  # type: ignore
+        for i in y:
+            c.rx(i, theta=np.pi / 2)  # type: ignore
+        s = c.state()  # type: ignore
+        if c.is_dm is False:
             p = backend.abs(s) ** 2
         else:
-            p = backend.real(backend.diagonal(s))
-        if status is None:
-            ch = backend.implicit_randc(a=2**self._nqubits, shape=[nbatch], p=p)
-        else:
-            ch = backend.stateful_randc(
-                status, a=2**self._nqubits, shape=[nbatch], p=p
-            )
-        prob = backend.gather1d(p, ch)
-        confg = backend.mod(
-            backend.right_shift(
-                ch[..., None], backend.reverse(backend.arange(self._nqubits))
-            ),
-            2,
+            p = backend.abs(backend.diagonal(s))
+        # readout error can be processed here later
+        mc = measurement_counts(
+            p,
+            counts=shots,
+            format="count_vector",
+            random_generator=random_generator,
+            jittable=True,
+            is_prob=True,
         )
-        r = list(zip(confg, prob))
-        if batch is None:
-            r = r[0]
+        x = list(x)
+        y = list(y)
+        z = list(z)
+        r = correlation_from_counts(x + y + z, mc)
+        # TODO(@refraction-ray): analytical standard deviation
         return r
 
+    sexpps = sample_expectation_ps
+
     def replace_inputs(self, inputs: Tensor) -> None:
         """
         Replace the input state with the circuit structure unchanged.
