@@ -15,6 +15,7 @@ import opt_einsum
 import tensornetwork as tn
 from tensornetwork.backend_contextmanager import get_default_backend
 
+from .backends.numpy_backend import NumpyBackend
 from .backends import get_backend  # type: ignore
 from .simplify import _multi_remove
 
@@ -25,7 +26,7 @@ thismodule = sys.modules[__name__]
 dtypestr = "complex64"
 rdtypestr = "float32"
 npdtype = np.complex64
-backend = get_backend("numpy")
+backend: NumpyBackend = get_backend("numpy")
 contractor = tn.contractors.auto
 # these above lines are just for mypy, it is not very good at evaluating runtime object
 
@@ -825,3 +826,28 @@ def runtime_contractor(*confargs: Any, **confkws: Any) -> Iterator[Any]:
     for module in sys.modules:
         if module.startswith(package_name):
             setattr(sys.modules[module], "contractor", old_contractor)
+
+
+def split_rules(
+    max_singular_values: Optional[int] = None,
+    max_truncation_err: Optional[float] = None,
+    relative: bool = False,
+) -> Any:
+    """
+    Obtain the direcionary of truncation rules
+
+    :param max_singular_values: The maximum number of singular values to keep.
+    :type max_singular_values: int, optional
+    :param max_truncation_err: The maximum allowed truncation error.
+    :type max_truncation_err: float, optional
+    :param relative: Multiply `max_truncation_err` with the largest singular value.
+    :type relative: bool, optional
+    """
+    rules: Any = {}
+    if max_singular_values is not None:
+        rules["max_singular_values"] = max_singular_values
+    if max_truncation_err is not None:
+        rules["max_truncattion_err"] = max_truncation_err
+    if relative is not None:
+        rules["relative"] = relative
+    return rules
