@@ -16,8 +16,6 @@ modulepath = os.path.dirname(os.path.dirname(thisfile))
 sys.path.insert(0, modulepath)
 import tensorcircuit as tc
 
-# TODO(@refraction-ray):replace all assert np.allclose with np.testing.assert_all_close !
-
 
 def test_wavefunction():
     qc = tc.Circuit(2)
@@ -1161,3 +1159,37 @@ def test_channel_auto_register(backend, highp):
     c.reset(0, status=0.8)
     s = c.state()
     np.testing.assert_allclose(s[0], 1.0, atol=1e-9)
+
+
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
+def test_circuit_to_json(backend):
+    c = tc.Circuit(3)
+    c.h(0)
+    c.CNOT(1, 2)
+    c.rxx(0, 2, theta=0.3)
+    c.crx(0, 1, theta=-0.8)
+    c.r(1, theta=tc.backend.ones([]), alpha=0.2)
+    c.toffoli(0, 2, 1)
+    c.ccnot(0, 1, 2)
+    c.multicontrol(1, 2, 0, ctrl=[0, 1], unitary=tc.gates._x_matrix)
+    s = c.to_json()
+    c2 = tc.Circuit.from_json(s)
+    print(c2.draw())
+    np.testing.assert_allclose(c.state(), c2.state(), atol=1e-5)
+
+
+def test_gate_count():
+    c = tc.Circuit(3)
+    c.h(0)
+    c.rx(1, theta=-0.2)
+    c.h(2)
+    c.multicontrol(0, 1, 2, ctrl=[0, 1], unitary=tc.gates._x_matrix)
+    c.toffoli(0, 2, 1)
+    c.ccnot(1, 2, 0)
+    c.ccx(1, 2, 0)
+    assert c.gate_count() == 7
+    assert c.gate_count(["h"]) == 2
+    assert c.gate_count(["ccnot"]) == 3
+    assert c.gate_count(["rx", "multicontrol"]) == 2
+    print(c.gate_summary())
+    # {'h': 2, 'rx': 1, 'multicontrol': 1, 'toffoli': 3}
